'use strict';

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

var pSeries = require('p-series');
var resolve = require('../resolve');
var fetchWelcome = require('../fetchWelcome');
var fetchUsername = require('../fetchUsername');
var fetchEmail = require('../fetchEmail');
var fetchNpmSaveExact = require('../fetchNpmSaveExact');
var fetchReadmes = require('../fetchReadmes');
var fetchComplete = require('../fetchComplete');
var getUserStorage = require('../getUserStorage');
var setUserStorage = require('../setUserStorage');
var renderClear = require('../renderClear');

/**
 * @param {Object} di - dependency injection
 * @returns {void}
 **/
function runCheck(_ref) {
	var _getUserStorage = _ref._getUserStorage,
	    _setUserStorage = _ref._setUserStorage,
	    _renderClear = _ref._renderClear,
	    _fetchWelcome = _ref._fetchWelcome,
	    _fetchUsername = _ref._fetchUsername,
	    _fetchEmail = _ref._fetchEmail,
	    _fetchNpmSaveExact = _ref._fetchNpmSaveExact,
	    _fetchReadmes = _ref._fetchReadmes,
	    _fetchComplete = _ref._fetchComplete;

	var store = _getUserStorage();

	pSeries([_fetchUsername, _fetchEmail, _fetchNpmSaveExact, _fetchWelcome, _fetchReadmes]).then(function (results) {
		var resultsStore = Object.assign.apply(Object, _toConsumableArray(results));
		var readmes = Object.assign({}, store.readmes, resultsStore.readmes);
		var newStore = Object.assign({}, store, resultsStore);
		newStore.readmes = readmes;
		_setUserStorage(newStore);
		_renderClear();

		pSeries([_fetchComplete.bind(null, resultsStore, undefined)]).then(function () {
			_renderClear();
		});
	});
}

module.exports = resolve(runCheck, {
	getUserStorage: getUserStorage,
	setUserStorage: setUserStorage,
	renderClear: renderClear,
	fetchWelcome: fetchWelcome,
	fetchUsername: fetchUsername,
	fetchEmail: fetchEmail,
	fetchNpmSaveExact: fetchNpmSaveExact,
	fetchReadmes: fetchReadmes,
	fetchComplete: fetchComplete
});
module.exports.runCheck = runCheck;